@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-extra
-version: 1.1.12.1
-id: conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
-key: condu_4ZAuoOa8iIULHSHRXw1JQ1
+version: 1.1.13.1
+id: conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+key: condu_EacXPOzC9rKEahE9Z8Nx3Y
 license: MIT
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -20,10 +20,10 @@ exposed-modules:
     Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
     Data.Conduit.Network.Unix
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.12.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.12.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.12.1
-hs-libraries: HSconduit-extra-1.1.12.1-4ZAuoOa8iIULHSHRXw1JQ1
+import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.13.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.13.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.13.1
+hs-libraries: HSconduit-extra-1.1.13.1-EacXPOzC9rKEahE9Z8Nx3Y
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
